@@ -1,19 +1,17 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2012 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2025 -- leonerd@leonerd.org.uk
 
-package overload::substr;
+package overload::substr 0.04;
 
-use strict;
+use v5.14;
 use warnings;
 
 use Carp;
 
-our $VERSION = '0.03';
-
 require XSLoader;
-XSLoader::load(__PACKAGE__, $VERSION );
+XSLoader::load(__PACKAGE__, our $VERSION );
 
 =head1 NAME
 
@@ -21,22 +19,24 @@ C<overload::substr> - overload Perl's C<substr()> function
 
 =head1 SYNOPSIS
 
- package My::Stringlike::Object;
+=for highlighter language=perl
 
- use overload::substr;
+   package My::Stringlike::Object;
 
- sub _substr
- {
-    my $self = shift;
-    if( @_ > 2 ) {
-       $self->replace_substr( @_ );
-    }
-    else {
-       return $self->get_substr( @_ );
-    }
- }
+   use overload::substr;
 
- ...
+   sub _substr
+   {
+      my $self = shift;
+      if( @_ > 2 ) {
+         $self->replace_substr( @_ );
+      }
+      else {
+         return $self->get_substr( @_ );
+      }
+   }
+
+   ...
 
 =head1 DESCRIPTION
 
@@ -47,17 +47,17 @@ It is invoked similarly to the C<overload> pragma, being passed a single named
 argument which should be a code reference or method name to implement the
 C<substr> function.
 
- use overload::substr substr => \&SUBSTR;
+   use overload::substr substr => \&SUBSTR;
 
- use overload::substr substr => "SUBSTR";
+   use overload::substr substr => "SUBSTR";
 
 The referred method will be invoked as per core's C<substr>; namely, it will
 take the string to be operated on (which will be an object in this case), an
 offset, optionally a length, and optionally a replacement.
 
- $str->SUBSTR( $offset );
- $str->SUBSTR( $offset, $length );
- $str->SUBSTR( $offset, $length, $replacement );
+   $str->SUBSTR( $offset );
+   $str->SUBSTR( $offset, $length );
+   $str->SUBSTR( $offset, $length, $replacement );
 
 In each case, whatever it returns will be the return value of the C<substr>
 function that invoked it.
